/*
 * extb plugin to VDR (C++)
 *
 * (C) 2004 Andreas Brachold <vdr04-at-deltab-dot-de>
 *
 * This code is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This code is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 * Or, point your browser to http://www.gnu.org/copyleft/gpl.html
 */


#include <string.h>
#include <stdio.h>
#include <stdlib.h>
#include <vdr/tools.h>
#include <vdr/config.h>
#include <vdr/i18n.h>
#include "setup.h"

/// The one and only Stored setup data
cExtbSetup theSetup;
const char * cExtbSetup::m_szMuteModes[cExtbSetup::eMuteModes_Cnt];
const char * cExtbSetup::m_szLEDModes[cExtbSetup::eLEDModes_Cnt];

/// Ctor, load default values
cExtbSetup::cExtbSetup(void)
{
  m_bHideMainMenuEntry = 0;
  m_nMuteMode = eMuteModes_AnalogDigital; 
  
  for(unsigned int n=0;n<memberof(m_nLEDMode);++n) 
    m_nLEDMode[n] = eLEDModes_Unused;
  
  for(unsigned int n=0;n<memberof(m_nOutputMode);++n) 
    m_nOutputMode[n] = eLEDModes_Unused;
}

/// compare profilenames and load there value 
bool cExtbSetup::SetupParse(const char *szName, const char *szValue)
{
  char sz[16];

  // HideMainMenuEntry
  if(!strcasecmp(szName, "HideMainMenuEntry")) {
    m_bHideMainMenuEntry = atoi(szValue) == 0?0:1;
    return true;
  }

  // MuteMode
  if(!strcasecmp(szName, "MuteMode")) {
    m_nMuteMode          = atoi(szValue) % eMuteModes_Cnt;
    return true;
  }

  // search parameter for all LEDs LEDMode1,LEDMode2...
  if(!strncasecmp(szName,"LEDMode",7)) {
    for(unsigned int n=0;n<memberof(m_nLEDMode);++n) {
        snprintf(sz,sizeof(sz),"LEDMode%d",n + 1);  
        if(!strcasecmp(szName, sz)) {
          m_nLEDMode[n]        = atoi(szValue) % eLEDModes_Cnt;
          return true;
        }
    }
  }
  
  // search parameter for all Outputs (Output1,Output2...)
  if(!strncasecmp(szName,"Output",6)) {
    for(unsigned int n=0;n<memberof(m_nOutputMode);++n) {
        snprintf(sz,sizeof(sz),"Output%d",n + 1);  
        if(!strcasecmp(szName, sz)) {
          m_nOutputMode[n]        = atoi(szValue) % eLEDModes_Cnt;
          return true;
        }
    }  
  }
  //Unknow parameter
  return false;
}


// Assign parameter and translated String
void cExtbSetup::LoadTranslatedStings(void)
{
  m_szMuteModes[eMuteModes_Analog]           = tr("only analog");
  m_szMuteModes[eMuteModes_Digital]          = tr("only digital");
  m_szMuteModes[eMuteModes_AnalogDigital]    = tr("analog & digital");

  m_szLEDModes[eLEDModes_Unused]             = tr("Unused");
  m_szLEDModes[eLEDModes_Off]                = tr("off");
  m_szLEDModes[eLEDModes_AlwaysOn]           = tr("Always on");
  m_szLEDModes[eLEDModes_AnyRecording]       = tr("Any Recording");
  m_szLEDModes[eLEDModes_RecordingOnCard1]   = tr("1st Card Recording");
  m_szLEDModes[eLEDModes_RecordingOnCard2]   = tr("2nd Card Recording");
  m_szLEDModes[eLEDModes_RecordingOnCard3]   = tr("3rd Card Recording");
  m_szLEDModes[eLEDModes_RecordingOnCard4]   = tr("4th Card Recording");
  m_szLEDModes[eLEDModes_AnyReplay]          = tr("Any replay");
  m_szLEDModes[eLEDModes_ReplayVDR]          = tr("VDR replay");
  m_szLEDModes[eLEDModes_ReplayDVD]          = tr("DVD replay");
  m_szLEDModes[eLEDModes_ReplayMP3]          = tr("MP3 replay");
  m_szLEDModes[eLEDModes_ChannelHasCA]       = tr("Channel has CA");
  m_szLEDModes[eLEDModes_ChannelHasDpid]     = tr("Channel has DPID");
  m_szLEDModes[eLEDModes_ChannelHasApid]     = tr("Channel has APID");
  m_szLEDModes[eLEDModes_ChannelHasTpid]     = tr("Channel has TPID");
  m_szLEDModes[eLEDModes_ChannelHasVpid]     = tr("Channel has VPID");
  m_szLEDModes[eLEDModes_ChannelIsRadio]     = tr("Listen radio");
  m_szLEDModes[eLEDModes_AudioMute]          = tr("Audio muted");
  m_szLEDModes[eLEDModes_AudioNotMute]       = tr("Audio not muted");
  
  m_szLEDModes[eLEDModes_DVD_AC3]            = tr("DVD AC3 playback");
  m_szLEDModes[eLEDModes_DVD_DTS]            = tr("DVD DTS playback");
  m_szLEDModes[eLEDModes_DVD_PCM]            = tr("DVD PCM playback");
  m_szLEDModes[eLEDModes_DVD_MP2]            = tr("DVD MP2 playback");
  m_szLEDModes[eLEDModes_DVD_4_3]            = tr("DVD 4:3 playback");
  m_szLEDModes[eLEDModes_DVD_16_9]           = tr("DVD 16:9 playback");
  // MP3 Plugin Playbackmodes
  m_szLEDModes[eLEDModes_MP3_Shuffle]        = tr("MP3 Shuffle play");
  m_szLEDModes[eLEDModes_MP3_Loop]           = tr("MP3 endless play");
}
